rustre_core::engine

Trait World

pub trait World {
    // Required methods
    fn input_files(&self) -> EcoVec<Source>;
    fn imported_file(
        &self,
        relative_to: &Source,
        path: &Path,
    ) -> Result<Source, FileError>;
}

Required Methods

fn input_files(&self) -> EcoVec<Source>

Sources of the compilation entry point(s)

A Rustre command can usually be invoked with multiple source files, in such a way that they would all be loaded in the same environment. This method should return them all. Keep in mind that this method will only return files that were explicitly loaded as input files, this means that files indirectly loaded using #include won’t be part of this list. Use the crate::all_sources query to get an exhaustive list of all files loaded directly and indirectly.

fn imported_file( &self, relative_to: &Source, path: &Path, ) -> Result<Source, FileError>

Parsed contents of a Lustre file